@@ -1,5 +1,4 @@
-from sadie.models import AbstractModel
-
+from sadie.models.base import AbstractModel
 
 class SimpleModel(AbstractModel):
     pass
